# PLADIF: Plots Attrakdiff graphs from CSV files

[Attrakdiff](http://www.attrakdiff.de/index-en.html) is a method to evaluate UX aspects like attractivity, usability, desirability, etc.

[Usabilla](https://usabilla.com/) is a software that is able to get feedback from online customers.

**PLADIF** is a simple tool that plots attrakdiff plots from CSV file (like those prroduced by Usabilla). It is based on Python, matplotlib, pandas and streamlit.

It takes Usabilla's CSV files as input, and produces attrakdiff graphes as output.


If PLADIF is useful, buy me a beer 🍺 !

Disclaimer: I am not affiliate to Usabilla nor Attrakdiff. This is a simple python tool for that. It uses (matplotlib)[https://matplotlib.org/] for the graphs and (pandas)[https://pandas.pydata.org/] for manipulatin the data (I am not a pandas expert, and probably some code that be done more efficiently with the adequate pandas methods). (Streamlit)[https://streamlit.io/] is used for the web app.
